@@ -3,6 +3,6 @@ import pytest
 from joseki.profiles.factory import factory
 
 
-def test_create() -> None:
+def test_create():
     with pytest.raises(ValueError):
         factory.create(identifier="invalid")
\ No newline at end of file
